==> fred-regal-0.3.1.tar.gz: fred-regal-0.3.1/regal/common.py <==
"""Common registry objects and decoder."""
from datetime import datetime
from typing import Any, Callable, Iterable, Optional, Sequence, Type, Union

from fred_api.registry.common_types_pb2 import PlaceAddress
from fred_api.registry.contact.contact_info_types_pb2 import ContactAddress
from fred_api.registry.contact.service_search_contact_grpc_pb2 import SearchContactHistoryReply, SearchContactReply
from fred_api.registry.domain.service_search_domain_grpc_pb2 import SearchDomainHistoryReply, SearchDomainReply
from fred_api.registry.keyset.service_search_keyset_grpc_pb2 import SearchKeysetHistoryReply, SearchKeysetReply
from fred_api.registry.nsset.service_search_nsset_grpc_pb2 import SearchNssetHistoryReply, SearchNssetReply
from fred_api.registry.object_events_pb2 import ObjectEvents as ObjectEventsMessage
from frgal import GrpcDecoder
from google.protobuf.message import Message
from pydantic import BaseModel

FuzzyValueType = Union[
    SearchContactReply.Data.FuzzyValue,
    SearchContactHistoryReply.Data.FuzzyValue,
    SearchDomainReply.Data.FuzzyValue,
    SearchDomainHistoryReply.Data.FuzzyValue,
    SearchKeysetReply.Data.FuzzyValue,
    SearchKeysetHistoryReply.Data.FuzzyValue,
    SearchNssetReply.Data.FuzzyValue,
    SearchNssetHistoryReply.Data.FuzzyValue,
]


class BaseId(str):
    """Identifier base class."""

    @classmethod
    def __get_validators__(cls) -> Iterable[Callable]:
        yield cls._validate

    @classmethod
    def _validate(cls, value: str) -> 'BaseId':
        return cls(value)

    def __repr__(self) -> str:
        return '{}({})'.format(self.__class__.__name__, super().__repr__())


class FuzzyValue(BaseModel):
    """Fuzzy value with lower and upper boundary."""

    lower_estimate: int
    upper_estimate: int


class DatetimeRange(BaseModel):
    """Datetime range."""

    start: Optional[datetime] = None
    end: Optional[datetime] = None


class ObjectEvent(BaseModel):
    """Registry object event detail.

    Attributes:
        registrar_handle: Handle of the registrar which triggered the event.
        timestamp: Timestamp of the event. It may not be present according to the API.
    """

    registrar_handle: str
    timestamp: Optional[datetime] = None


class ObjectEvents(BaseModel):
    """Registry object events collection."""

    registered: ObjectEvent
    transferred: ObjectEvent
    updated: Optional[ObjectEvent] = None
    unregistered: Optional[ObjectEvent] = None


class Address(BaseModel):
    """Place address."""

    street: Sequence[str]
    city: str
    state_or_province: str = ''
    postal_code: Optional[str] = None
    country_code: Optional[str] = None
    company: Optional[str] = None


class RegistryDecoder(GrpcDecoder):
    """Decoder for structures shared among multiple services."""

    decode_unset_messages = False
    decode_empty_string_none = False

    def __init__(self) -> None:
        super().__init__()
        self.set_decoder(PlaceAddress, self._decode_address)
        self.set_decoder(ContactAddress, self._decode_address)
        self.set_decoder(ObjectEventsMessage.EventData, self._decode_object_event)
        self.set_decoder(ObjectEventsMessage, self._decode_object_events)

        self.set_decoder(SearchContactReply.Data.FuzzyValue, self._decode_fuzzy_value)
        self.set_decoder(SearchContactHistoryReply.Data.FuzzyValue, self._decode_fuzzy_value)
        self.set_decoder(SearchDomainReply.Data.FuzzyValue, self._decode_fuzzy_value)
        self.set_decoder(SearchDomainHistoryReply.Data.FuzzyValue, self._decode_fuzzy_value)
        self.set_decoder(SearchKeysetReply.Data.FuzzyValue, self._decode_fuzzy_value)
        self.set_decoder(SearchKeysetHistoryReply.Data.FuzzyValue, self._decode_fuzzy_value)
        self.set_decoder(SearchNssetReply.Data.FuzzyValue, self._decode_fuzzy_value)
        self.set_decoder(SearchNssetHistoryReply.Data.FuzzyValue, self._decode_fuzzy_value)

    def _decode_fuzzy_value(self, value: FuzzyValueType) -> FuzzyValue:
        """Fuzzy value decoder."""
        return FuzzyValue(lower_estimate=value.lower_estimate, upper_estimate=value.upper_estimate)

    def _decode_address(self, value: Any) -> Address:
        """Address decoder."""
        return Address(**self._decode_message(value))

    def _decode_object_event(self, value: ObjectEventsMessage.EventData) -> Optional[ObjectEvent]:
        """Object event decoder."""
        registrar_handle = self.decode(value.registrar_handle)
        timestamp = self.decode(value.timestamp)
        if registrar_handle or timestamp:
            return ObjectEvent(registrar_handle=registrar_handle, timestamp=timestamp)
        else:
            return None

    def _decode_object_events(self, value: ObjectEventsMessage) -> ObjectEvents:
        """Object events decoder."""
        return ObjectEvents(
            registered=self.decode(value.registered),
            transferred=self.decode(value.transferred),
            updated=self.decode(value.updated),
            unregistered=self.decode(value.unregistered),
        )


def set_request_pagination(request: Message, *, page_token: str = None, page_size: int = None) -> None:
    """Set pagination on request."""
    if page_token is not None:
        request.pagination.page_token = page_token  # type: ignore[attr-defined]
    if page_size is not None:
        request.pagination.page_size = page_size  # type: ignore[attr-defined]


def _set_sponsoring_registrar(cls: Type[BaseModel], values: dict) -> dict:
    """Help function for getting sponsoring registrar from events."""
    if values.get('sponsoring_registrar') is None and values.get('events') and values['events'].get('transferred'):
        values['sponsoring_registrar'] = values['events']['transferred'].get('registrar_handle')
    return values

==> fred-regal-0.5.1.tar.gz: fred-regal-0.5.1/regal/common.py <==
"""Common registry objects and decoder."""
from datetime import datetime
from typing import Any, Callable, Iterable, Optional, Sequence, Type, Union

from fred_api.registry.common_types_pb2 import PlaceAddress
from fred_api.registry.contact.contact_info_types_pb2 import ContactAddress
from fred_api.registry.contact.service_search_contact_grpc_pb2 import SearchContactHistoryReply, SearchContactReply
from fred_api.registry.domain.service_search_domain_grpc_pb2 import SearchDomainHistoryReply, SearchDomainReply
from fred_api.registry.keyset.service_search_keyset_grpc_pb2 import SearchKeysetHistoryReply, SearchKeysetReply
from fred_api.registry.nsset.service_search_nsset_grpc_pb2 import SearchNssetHistoryReply, SearchNssetReply
from fred_api.registry.object_events_pb2 import ObjectEvents as ObjectEventsMessage
from frgal import GrpcDecoder
from google.protobuf.message import Message
from pydantic import BaseModel

FuzzyValueType = Union[
    SearchContactReply.Data.FuzzyValue,
    SearchContactHistoryReply.Data.FuzzyValue,
    SearchDomainReply.Data.FuzzyValue,
    SearchDomainHistoryReply.Data.FuzzyValue,
    SearchKeysetReply.Data.FuzzyValue,
    SearchKeysetHistoryReply.Data.FuzzyValue,
    SearchNssetReply.Data.FuzzyValue,
    SearchNssetHistoryReply.Data.FuzzyValue,
]


class BaseId(str):
    """Identifier base class."""

    @classmethod
    def __get_validators__(cls) -> Iterable[Callable]:
        yield cls._validate

    @classmethod
    def _validate(cls, value: str) -> 'BaseId':
        return cls(value)

    def __repr__(self) -> str:
        return '{}({})'.format(self.__class__.__name__, super().__repr__())


class FuzzyValue(BaseModel):
    """Fuzzy value with lower and upper boundary."""

    lower_estimate: int
    upper_estimate: int


class DatetimeRange(BaseModel):
    """Datetime range."""

    start: Optional[datetime] = None
    end: Optional[datetime] = None


class ObjectEvent(BaseModel):
    """Registry object event detail.

    Attributes:
        registrar_handle: Handle of the registrar which triggered the event.
        timestamp: Timestamp of the event. It may not be present according to the API.
    """

    registrar_handle: str
    timestamp: Optional[datetime] = None


class ObjectEvents(BaseModel):
    """Registry object events collection."""

    registered: ObjectEvent
    transferred: ObjectEvent
    updated: Optional[ObjectEvent] = None
    unregistered: Optional[ObjectEvent] = None


class Address(BaseModel):
    """Place address."""

    street: Sequence[str]
    city: str
    state_or_province: str = ''
    postal_code: Optional[str] = None
    country_code: Optional[str] = None
    company: Optional[str] = None


class RegistryDecoder(GrpcDecoder):
    """Decoder for structures shared among multiple services."""

    decode_unset_messages = False
    decode_empty_string_none = False

    def __init__(self) -> None:
        super().__init__()
        self.set_decoder(PlaceAddress, self._decode_address)
        self.set_decoder(ContactAddress, self._decode_address)
        self.set_decoder(ObjectEventsMessage.EventData, self._decode_object_event)
        self.set_decoder(ObjectEventsMessage, self._decode_object_events)

        self.set_decoder(SearchContactReply.Data.FuzzyValue, self._decode_fuzzy_value)
        self.set_decoder(SearchContactHistoryReply.Data.FuzzyValue, self._decode_fuzzy_value)
        self.set_decoder(SearchDomainReply.Data.FuzzyValue, self._decode_fuzzy_value)
        self.set_decoder(SearchDomainHistoryReply.Data.FuzzyValue, self._decode_fuzzy_value)
        self.set_decoder(SearchKeysetReply.Data.FuzzyValue, self._decode_fuzzy_value)
        self.set_decoder(SearchKeysetHistoryReply.Data.FuzzyValue, self._decode_fuzzy_value)
        self.set_decoder(SearchNssetReply.Data.FuzzyValue, self._decode_fuzzy_value)
        self.set_decoder(SearchNssetHistoryReply.Data.FuzzyValue, self._decode_fuzzy_value)

    def _decode_fuzzy_value(self, value: FuzzyValueType) -> FuzzyValue:
        """Fuzzy value decoder."""
        return FuzzyValue(lower_estimate=value.lower_estimate, upper_estimate=value.upper_estimate)

    def _decode_address(self, value: Any) -> Address:
        """Address decoder."""
        return Address(**self._decode_message(value))

    def _decode_object_event(self, value: ObjectEventsMessage.EventData) -> Optional[ObjectEvent]:
        """Object event decoder."""
        registrar_handle = self.decode(value.registrar_handle)
        timestamp = self.decode(value.timestamp)
        if registrar_handle or timestamp:
            return ObjectEvent(registrar_handle=registrar_handle, timestamp=timestamp)
        else:
            return None

    def _decode_object_events(self, value: ObjectEventsMessage) -> ObjectEvents:
        """Object events decoder."""
        return ObjectEvents(
            registered=self.decode(value.registered),
            transferred=self.decode(value.transferred),
            updated=self.decode(value.updated),
            unregistered=self.decode(value.unregistered),
        )


def set_request_pagination(request: Message, *, page_token: str = None, page_size: int = None) -> None:
    """Set pagination on request."""
    if page_token is not None:
        request.pagination.page_token = page_token  # type: ignore[attr-defined]
    if page_size is not None:
        request.pagination.page_size = page_size  # type: ignore[attr-defined]


def _set_sponsoring_registrar(cls: Type[BaseModel], values: dict) -> dict:
    """Help function for getting sponsoring registrar from events."""
    events = values.get('events')
    if values.get('sponsoring_registrar') is None and events:
        if isinstance(events, ObjectEvents):
            values['sponsoring_registrar'] = events.transferred.registrar_handle
        elif isinstance(events, dict) and 'transferred' in events:
            values['sponsoring_registrar'] = events['transferred'].get('registrar_handle')
    return values
